module.exports = defineTest({
	description: 'imports a default function'
});
